==> zio-aws-dataexchange_2.13-5.17.129.2-sources.jar: zio/aws/dataexchange/model/ImportAssetFromSignedUrlRequestDetails.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.{
  __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093,
  Id,
  AssetName
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class ImportAssetFromSignedUrlRequestDetails(
    assetName: AssetName,
    dataSetId: Id,
    md5Hash: __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093,
    revisionId: Id
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.ImportAssetFromSignedUrlRequestDetails = {
    import ImportAssetFromSignedUrlRequestDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.ImportAssetFromSignedUrlRequestDetails
      .builder()
      .assetName(AssetName.unwrap(assetName): java.lang.String)
      .dataSetId(Id.unwrap(dataSetId): java.lang.String)
      .md5Hash(
        __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093.unwrap(
          md5Hash
        ): java.lang.String
      )
      .revisionId(Id.unwrap(revisionId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails.ReadOnly =
    zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails
      .wrap(buildAwsValue())
}
object ImportAssetFromSignedUrlRequestDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.ImportAssetFromSignedUrlRequestDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails =
      zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails(
        assetName,
        dataSetId,
        md5Hash,
        revisionId
      )
    def assetName: AssetName
    def dataSetId: Id
    def md5Hash: __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093
    def revisionId: Id
    def getAssetName: ZIO[Any, Nothing, AssetName] = ZIO.succeed(assetName)
    def getDataSetId: ZIO[Any, Nothing, Id] = ZIO.succeed(dataSetId)
    def getMd5Hash
        : ZIO[Any, Nothing, __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093] =
      ZIO.succeed(md5Hash)
    def getRevisionId: ZIO[Any, Nothing, Id] = ZIO.succeed(revisionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.ImportAssetFromSignedUrlRequestDetails
  ) extends zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails.ReadOnly {
    override val assetName: AssetName =
      zio.aws.dataexchange.model.primitives.AssetName(impl.assetName())
    override val dataSetId: Id =
      zio.aws.dataexchange.model.primitives.Id(impl.dataSetId())
    override val md5Hash: __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093 =
      zio.aws.dataexchange.model.primitives
        .__stringMin24Max24PatternAZaZ094AZaZ092AZaZ093(impl.md5Hash())
    override val revisionId: Id =
      zio.aws.dataexchange.model.primitives.Id(impl.revisionId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.ImportAssetFromSignedUrlRequestDetails
  ): zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-dataexchange_2.13-5.17.295.13-sources.jar: zio/aws/dataexchange/model/ImportAssetFromSignedUrlRequestDetails.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.{
  __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093,
  Id,
  AssetName
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class ImportAssetFromSignedUrlRequestDetails(
    assetName: AssetName,
    dataSetId: Id,
    md5Hash: __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093,
    revisionId: Id
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.ImportAssetFromSignedUrlRequestDetails = {
    import ImportAssetFromSignedUrlRequestDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.ImportAssetFromSignedUrlRequestDetails
      .builder()
      .assetName(AssetName.unwrap(assetName): java.lang.String)
      .dataSetId(Id.unwrap(dataSetId): java.lang.String)
      .md5Hash(md5Hash: java.lang.String)
      .revisionId(Id.unwrap(revisionId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails.ReadOnly =
    zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails
      .wrap(buildAwsValue())
}
object ImportAssetFromSignedUrlRequestDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.ImportAssetFromSignedUrlRequestDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails =
      zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails(
        assetName,
        dataSetId,
        md5Hash,
        revisionId
      )
    def assetName: AssetName
    def dataSetId: Id
    def md5Hash: __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093
    def revisionId: Id
    def getAssetName: ZIO[Any, Nothing, AssetName] = ZIO.succeed(assetName)
    def getDataSetId: ZIO[Any, Nothing, Id] = ZIO.succeed(dataSetId)
    def getMd5Hash
        : ZIO[Any, Nothing, __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093] =
      ZIO.succeed(md5Hash)
    def getRevisionId: ZIO[Any, Nothing, Id] = ZIO.succeed(revisionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.ImportAssetFromSignedUrlRequestDetails
  ) extends zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails.ReadOnly {
    override val assetName: AssetName =
      zio.aws.dataexchange.model.primitives.AssetName(impl.assetName())
    override val dataSetId: Id =
      zio.aws.dataexchange.model.primitives.Id(impl.dataSetId())
    override val md5Hash: __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093 =
      impl.md5Hash(): __stringMin24Max24PatternAZaZ094AZaZ092AZaZ093
    override val revisionId: Id =
      zio.aws.dataexchange.model.primitives.Id(impl.revisionId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.ImportAssetFromSignedUrlRequestDetails
  ): zio.aws.dataexchange.model.ImportAssetFromSignedUrlRequestDetails.ReadOnly =
    new Wrapper(impl)
}
